==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QAccessibleTextSelectionEvent_shell.cpp <==
#include "QAccessibleTextSelectionEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleTextSelectionEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleTextSelectionEvent")
    QAccessibleTextSelectionEvent *_ptr = reinterpret_cast<QAccessibleTextSelectionEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleTextSelectionEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleTextSelectionEvent_shell) ); }

jmethodID QAccessibleTextSelectionEvent_shell::__shell_javaMethod(int pos) const { return QAccessibleTextSelectionEvent_shell::__shell()->javaMethod(typeid(QAccessibleTextSelectionEvent), pos); }

// emitting (writeShellConstructor)
QAccessibleTextSelectionEvent_shell::QAccessibleTextSelectionEvent_shell(QAccessibleInterface* iface0, int start1, int end2)
    : QAccessibleTextSelectionEvent(iface0, start1, end2)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent_shell(QAccessibleInterface* iface0, int start1, int end2)", QAccessibleTextSelectionEvent_shell::__shell())
    QAccessibleTextSelectionEvent_shell::__shell()->constructed(typeid(QAccessibleTextSelectionEvent));
}

QAccessibleTextSelectionEvent_shell::QAccessibleTextSelectionEvent_shell(QObject* obj0, int start1, int end2)
    : QAccessibleTextSelectionEvent(obj0, start1, end2)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent_shell(QObject* obj0, int start1, int end2)", QAccessibleTextSelectionEvent_shell::__shell())
    QAccessibleTextSelectionEvent_shell::__shell()->constructed(typeid(QAccessibleTextSelectionEvent));
}

// emitting (writeShellDestructor)
QAccessibleTextSelectionEvent_shell::~QAccessibleTextSelectionEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleTextSelectionEvent::~QAccessibleTextSelectionEvent()", QAccessibleTextSelectionEvent_shell::__shell())
    QAccessibleTextSelectionEvent_shell::__shell()->destructed(typeid(QAccessibleTextSelectionEvent));
}

void QAccessibleTextSelectionEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleTextSelectionEvent_shell*>(ptr)->QAccessibleTextSelectionEvent_shell::__shell()->tryDeleteShell(typeid(QAccessibleTextSelectionEvent));
}

// emitting Virtual overrides (virtualFunctions)
QAccessibleInterface* QAccessibleTextSelectionEvent_shell::accessibleInterface() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleTextSelectionEvent::", QAccessibleTextSelectionEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QAccessibleInterface*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleTextSelectionEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QAccessibleInterface* >(__jni_env, __java_return_value);
                } else {
                    QAccessibleTextSelectionEvent_shell::__shell()->warnForMethod("QAccessibleTextSelectionEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleTextSelectionEvent::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QAccessibleEvent::accessibleInterface();
        }
    }else{
        return QAccessibleEvent::accessibleInterface();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QAccessibleTextSelectionEvent(QAccessibleInterface*,int,int)
void __qt_construct_QAccessibleTextSelectionEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleTextSelectionEvent(QAccessibleInterface*,int,int)")
    jobject iface0 = __java_arguments[0].l;
    QAccessibleInterface* __qt_iface0 = qtjambi_cast<QAccessibleInterface* >(__jni_env, iface0);
    jint start1 = __java_arguments[1].i;
    Q_UNUSED(start1)
    jint end2 = __java_arguments[2].i;
    Q_UNUSED(end2)
    QAccessibleTextSelectionEvent *__qt_this = new(__qtjambi_ptr) QAccessibleTextSelectionEvent_shell(__qt_iface0, static_cast<int>(start1), static_cast<int>(end2));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QAccessibleTextSelectionEvent(QObject*,int,int)
void __qt_construct_QAccessibleTextSelectionEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleTextSelectionEvent(QObject*,int,int)")
    jobject obj0 = __java_arguments[0].l;
    QObject* __qt_obj0 = qtjambi_cast<QObject* >(__jni_env, obj0);
    jint start1 = __java_arguments[1].i;
    Q_UNUSED(start1)
    jint end2 = __java_arguments[2].i;
    Q_UNUSED(end2)
    QAccessibleTextSelectionEvent *__qt_this = new(__qtjambi_ptr) QAccessibleTextSelectionEvent_shell(__qt_obj0, static_cast<int>(start1), static_cast<int>(end2));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QAccessibleTextSelectionEvent_shell
void __qt_destruct_QAccessibleTextSelectionEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleTextSelectionEvent")
    reinterpret_cast<QAccessibleTextSelectionEvent_shell*>(ptr)->~QAccessibleTextSelectionEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent(QAccessibleInterface*,int,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextSelectionEvent_initialize_1native__Lio_qt_gui_QAccessibleTextSelectionEvent_2Lio_qt_gui_QAccessibleInterface_2II)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject iface0,
 jint start1,
 jint end2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent(QAccessibleInterface*,int,int)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].l = iface0;
        arguments[1].i = start1;
        arguments[2].i = end2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleTextSelectionEvent_0, sizeof(QAccessibleTextSelectionEvent_shell), typeid(QAccessibleTextSelectionEvent), true, &deleter_QAccessibleTextSelectionEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent(QObject*,int,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextSelectionEvent_initialize_1native__Lio_qt_gui_QAccessibleTextSelectionEvent_2Lio_qt_core_QObject_2II)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject obj0,
 jint start1,
 jint end2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent(QObject*,int,int)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].l = obj0;
        arguments[1].i = start1;
        arguments[2].i = end2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleTextSelectionEvent_1, sizeof(QAccessibleTextSelectionEvent_shell), typeid(QAccessibleTextSelectionEvent), true, &deleter_QAccessibleTextSelectionEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleTextSelectionEvent::selectionEnd()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextSelectionEvent_selectionEnd_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleTextSelectionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleTextSelectionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleTextSelectionEvent::selectionEnd()const", __qt_this)
        __java_return_value = __qt_this->selectionEnd();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAccessibleTextSelectionEvent::selectionStart()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextSelectionEvent_selectionStart_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleTextSelectionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleTextSelectionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleTextSelectionEvent::selectionStart()const", __qt_this)
        __java_return_value = __qt_this->selectionStart();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAccessibleTextSelectionEvent::setSelection(int,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextSelectionEvent_setSelection_1native_1int_1int__JII)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint start0,
 jint end1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAccessibleTextSelectionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleTextSelectionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleTextSelectionEvent::setSelection(int,int)", __qt_this)
        __qt_this->setSelection(static_cast<int>(start0), static_cast<int>(end1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleTextSelectionEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAccessibleTextSelectionEvent>("QAccessibleTextSelectionEvent", "io/qt/gui/QAccessibleTextSelectionEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "accessibleInterface", "()Lio/qt/gui/QAccessibleInterface;")});
    registerConstructorInfos(typeId, &__qt_destruct_QAccessibleTextSelectionEvent, {
        ConstructorInfo(&__qt_construct_QAccessibleTextSelectionEvent_0, "Lio/qt/gui/QAccessibleInterface;II")
       ,ConstructorInfo(&__qt_construct_QAccessibleTextSelectionEvent_1, "Lio/qt/core/QObject;II")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleTextSelectionEvent);
    registerSizeOfShell(typeId, sizeof(QAccessibleTextSelectionEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QAccessibleTextCursorEvent, QAccessibleTextSelectionEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QAccessibleTextSelectionEvent_shell.cpp <==
#include "QAccessibleTextSelectionEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleTextSelectionEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleTextSelectionEvent")
    QAccessibleTextSelectionEvent *_ptr = reinterpret_cast<QAccessibleTextSelectionEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleTextSelectionEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleTextSelectionEvent_shell) ); }

jmethodID QAccessibleTextSelectionEvent_oshell::__shell_javaMethod(int pos) const { return QAccessibleTextSelectionEvent_shell::__shell()->javaMethod(typeid(QAccessibleTextSelectionEvent), pos); }

// emitting (writeShellDestructor)
QAccessibleTextSelectionEvent_shell::~QAccessibleTextSelectionEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleTextSelectionEvent::~QAccessibleTextSelectionEvent()", this)
    QAccessibleTextSelectionEvent_shell::__shell()->destructed(typeid(QAccessibleTextSelectionEvent));
}

// emitting (writeShellConstructor)
QAccessibleTextSelectionEvent_shell::QAccessibleTextSelectionEvent_shell(QAccessibleInterface* iface0, int start1, int end2)
    : QAccessibleTextSelectionEvent(iface0, start1, end2)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent_shell(QAccessibleInterface* iface0, int start1, int end2)", this)
    QAccessibleTextSelectionEvent_shell::__shell()->constructed(typeid(QAccessibleTextSelectionEvent));
}

QAccessibleTextSelectionEvent_shell::QAccessibleTextSelectionEvent_shell(QObject* obj0, int start1, int end2)
    : QAccessibleTextSelectionEvent(obj0, start1, end2)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent_shell(QObject* obj0, int start1, int end2)", this)
    QAccessibleTextSelectionEvent_shell::__shell()->constructed(typeid(QAccessibleTextSelectionEvent));
}

void QAccessibleTextSelectionEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleTextSelectionEvent_shell*>(ptr)->QAccessibleTextSelectionEvent_shell::__shell()->tryDeleteShell(typeid(QAccessibleTextSelectionEvent));
}

void QAccessibleTextSelectionEvent_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleTextSelectionEvent_oshell*>(ptr)->QAccessibleTextSelectionEvent_oshell::__shell()->tryDeleteShell(typeid(QAccessibleTextSelectionEvent));
}

// emitting Virtual overrides (virtualFunctions)
QAccessibleInterface* QAccessibleTextSelectionEvent_oshell::accessibleInterface() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QAccessibleInterface*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleTextSelectionEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = qtjambi_cast<QAccessibleInterface*>(__jni_env, __java_return_value);
                } else {
                    QAccessibleTextSelectionEvent_shell::__shell()->warnForMethod("QAccessibleTextSelectionEvent::accessibleInterface()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QAccessibleTextSelectionEvent::accessibleInterface()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QAccessibleEvent::accessibleInterface();
        }
    }else{
        return QAccessibleEvent::accessibleInterface();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QAccessibleTextSelectionEvent(QAccessibleInterface*,int,int)
void __qt_construct_QAccessibleTextSelectionEvent_QAccessibleInterface_ptr_int_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleTextSelectionEvent(QAccessibleInterface*,int,int)")
    jobject iface0 = __java_arguments[0].l;
    QAccessibleInterface* __qt_iface0 = qtjambi_cast<QAccessibleInterface*>(__jni_env, iface0);
    jint start1 = __java_arguments[1].i;
    Q_UNUSED(start1)
    jint end2 = __java_arguments[2].i;
    Q_UNUSED(end2)
    QAccessibleTextSelectionEvent *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QAccessibleTextSelectionEvent_oshell(__qt_iface0, static_cast<int>(start1), static_cast<int>(end2));
    else
        __qt_this = new(__qtjambi_ptr) QAccessibleTextSelectionEvent_shell(__qt_iface0, static_cast<int>(start1), static_cast<int>(end2));
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent(QAccessibleInterface*,int,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextSelectionEvent_initialize_1native__Lio_qt_gui_QAccessibleTextSelectionEvent_2Lio_qt_gui_QAccessibleInterface_2II)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject iface0,
 jint start1,
 jint end2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent(QAccessibleInterface*,int,int)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].l = iface0;
        arguments[1].i = start1;
        arguments[2].i = end2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleTextSelectionEvent_QAccessibleInterface_ptr_int_int, sizeof(QAccessibleTextSelectionEvent_shell), typeid(QAccessibleTextSelectionEvent), 0, true, &deleter_QAccessibleTextSelectionEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QAccessibleTextSelectionEvent(QObject*,int,int)
void __qt_construct_QAccessibleTextSelectionEvent_QObject_ptr_int_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleTextSelectionEvent(QObject*,int,int)")
    jobject obj0 = __java_arguments[0].l;
    QObject* __qt_obj0 = qtjambi_cast<QObject*>(__jni_env, obj0);
    jint start1 = __java_arguments[1].i;
    Q_UNUSED(start1)
    jint end2 = __java_arguments[2].i;
    Q_UNUSED(end2)
    QAccessibleTextSelectionEvent *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QAccessibleTextSelectionEvent_oshell(__qt_obj0, static_cast<int>(start1), static_cast<int>(end2));
    else
        __qt_this = new(__qtjambi_ptr) QAccessibleTextSelectionEvent_shell(__qt_obj0, static_cast<int>(start1), static_cast<int>(end2));
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent(QObject*,int,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextSelectionEvent_initialize_1native__Lio_qt_gui_QAccessibleTextSelectionEvent_2Lio_qt_core_QObject_2II)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject obj0,
 jint start1,
 jint end2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleTextSelectionEvent::QAccessibleTextSelectionEvent(QObject*,int,int)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].l = obj0;
        arguments[1].i = start1;
        arguments[2].i = end2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleTextSelectionEvent_QObject_ptr_int_int, sizeof(QAccessibleTextSelectionEvent_shell), typeid(QAccessibleTextSelectionEvent), 0, true, &deleter_QAccessibleTextSelectionEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAccessibleTextSelectionEvent_shell
void __qt_destruct_QAccessibleTextSelectionEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleTextSelectionEvent")
    reinterpret_cast<QAccessibleTextSelectionEvent_shell*>(ptr)->~QAccessibleTextSelectionEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleTextSelectionEvent::selectionEnd()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextSelectionEvent_selectionEnd_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleTextSelectionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleTextSelectionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleTextSelectionEvent::selectionEnd()const", __this_nativeId)
        __java_return_value = __qt_this->selectionEnd();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAccessibleTextSelectionEvent::selectionStart()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextSelectionEvent_selectionStart_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleTextSelectionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleTextSelectionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleTextSelectionEvent::selectionStart()const", __this_nativeId)
        __java_return_value = __qt_this->selectionStart();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAccessibleTextSelectionEvent::setSelection(int,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextSelectionEvent_setSelection_1native_1int_1int__JII)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint start0,
 jint end1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAccessibleTextSelectionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleTextSelectionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleTextSelectionEvent::setSelection(int,int)", __this_nativeId)
        __qt_this->setSelection(static_cast<int>(start0), static_cast<int>(end1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleTextSelectionEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAccessibleTextSelectionEvent>("QAccessibleTextSelectionEvent", "io/qt/gui/QAccessibleTextSelectionEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "accessibleInterface", "()Lio/qt/gui/QAccessibleInterface;")});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QAccessibleTextSelectionEvent, {
        ConstructorInfo(&__qt_construct_QAccessibleTextSelectionEvent_QAccessibleInterface_ptr_int_int, "Lio/qt/gui/QAccessibleInterface;II")
       ,ConstructorInfo(&__qt_construct_QAccessibleTextSelectionEvent_QObject_ptr_int_int, "Lio/qt/core/QObject;II")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleTextSelectionEvent);
    registerSizeOfShell(typeId, sizeof(QAccessibleTextSelectionEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QAccessibleTextCursorEvent, QAccessibleTextSelectionEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
